import { Phone, Menu, X } from "lucide-react";
import { useEffect, useState } from "react";
import { motion, useScroll, useTransform, AnimatePresence, easeOut } from "framer-motion";
import { Link } from "wouter";

export default function Header() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const { scrollY } = useScroll();
  const [isMobile, setIsMobile] = useState(window.innerWidth < 768);

  useEffect(() => {
    const handleResize = () => {
      setIsMobile(window.innerWidth < 768);
    };

    window.addEventListener('resize', handleResize);
    return () => window.removeEventListener('resize', handleResize);
  }, []);

  // Enhanced scroll-based transforms with proper easing
  const logoScale = useTransform(scrollY,
    [0, 100],
    [1, 0.7],
    { ease: easeOut }
  );

  const logoHeight = useTransform(scrollY, 
    [0, 100], 
    isMobile ? ["300px", "150px"] : ["190px", "160px"],
    { ease: easeOut }
  );

  const headerOpacity = useTransform(scrollY,
    [0, 50],
    [1, 1],
    { ease: easeOut }
  );

  const triangleWidth = useTransform(scrollY,
    [0, 100],
    isMobile ? ["320px", "180px"] : ["490px", "300px"],
    { ease: easeOut }
  );

  const triangleHeight = useTransform(scrollY,
    [0, 100],
    isMobile ? ["280px", "160px"] : ["305px", "164px"],
    { ease: easeOut }
  );

  return (
    <div className="fixed w-full top-0 z-50">
      {/* Mobile Header */}
      <div className="lg:hidden">
        <motion.nav 
          className="bg-blue-800 shadow-lg fixed w-full top-0 z-50 transition-all duration-300"
          style={{ 
            opacity: headerOpacity,
            height: useTransform(scrollY, 
              [0, 100], 
              ["200px", "110px"]
            ),
          }}
        >
          <div className="px-4 h-full flex items-center">
            <div className="flex justify-between items-center w-full">
              {/* Phone number - hidden on smallest screens */}
              <div className="hidden sm:flex items-center space-x-2">
                <Phone className="h-5 w-5 text-white" />
                <a href="tel:(585)-222-2564" className="text-white font-bold hover:text-blue-200 transition-colors">
                  (585) 222-CLOG
                </a>
              </div>
              {/* Logo */}
              <motion.div 
                className="transition-all duration-300"
                style={{
                  height: useTransform(scrollY,
                    [0, 100],
                    ["165px", "85px"]
                  )
                }}
              >
                <Link href="/">
                  <img 
                    src="/DB Full Logo White Text Small.png" 
                    alt="Drain Busters"
                    className="h-full w-auto object-contain"
                    width="320"
                    height="85"
                    loading="eager"
                    fetchPriority="high"
                  />
                </Link>
              </motion.div>
              {/* Book Now Button - hidden on smallest screens */}
              <Link href="/bookings" className="hidden sm:block bg-blue-600 hover:bg-blue-700 text-white px-4 py-2 rounded-full font-bold transition-colors">
                Book Now
              </Link>
            </div>
          </div>
        </motion.nav>
      </div>

      {/* Desktop Header */}
      <div className="hidden lg:block">
        <motion.nav 
          className="bg-blue-800 shadow-lg"
          style={{ opacity: headerOpacity }}
        >
          <div className="container mx-auto px-4 relative">
            <div className="flex justify-between items-center h-24">
              {/* Phone number */}
              <motion.div 
                className="flex items-center ml-4 lg:ml-12"
                initial={{ opacity: 0, x: -20 }}
                animate={{ opacity: 1, x: 0 }}
                transition={{ delay: 0.3, duration: 0.5 }}
              >
                <div className="flex items-center space-x-2">
                  <Phone className="h-5 w-5 text-white" />
                  <a href="tel:(585)-222-2564" className="text-white font-bold hover:text-blue-200 transition-colors">
                    (585) 222-CLOG
                  </a>
                </div>
              </motion.div>

              {/* Logo with triangle background */}
              <div className="absolute left-1/2 transform -translate-x-1/2 flex flex-col items-center">
                <motion.div 
                  className="absolute bg-blue-800" 
                  style={{
                    width: triangleWidth,
                    height: triangleHeight,
                    borderRadius: '0 0 10% 10%',
                    transform: 'translateY(-20px)',
                    zIndex: -1
                  }}
                  initial={{ scaleY: 0 }}
                  animate={{ scaleY: 1 }}
                  transition={{ duration: 0.6, ease: "easeOut" }}
                />
                <motion.div
                  style={{ 
                    marginTop: useTransform(scrollY,
                      [0, 100],
                      ["96px", "20px"],
                      { ease: easeOut }
                    ),
                    scale: logoScale
                  }}
                  initial={{ y: -50, opacity: 0 }}
                  animate={{ y: 0, opacity: 1 }}
                  transition={{ delay: 0.2, duration: 0.7, ease: "easeOut" }}
                >
                  <Link href="/">
                    <motion.img 
                      src="/DB Full Logo White Text Small.png" 
                      alt="Drain Busters" 
                      style={{ height: logoHeight, width: 'auto' }}
                      className="transition-all duration-300"
                      whileHover={{ scale: 1.02 }}
                      transition={{ duration: 0.2 }}
                      width="320"
                      height="160"
                      loading="eager"
                      fetchPriority="high"
                    />
                  </Link>
                </motion.div>
              </div>

              {/* Book Now Button */}
              <motion.div 
                className="flex items-center mr-4 lg:mr-12"
                initial={{ opacity: 0, x: 20 }}
                animate={{ opacity: 1, x: 0 }}
                transition={{ delay: 0.3, duration: 0.5 }}
              >
                <Link href="/bookings" className="bg-blue-600 hover:bg-blue-700 text-white px-6 py-3 rounded-full font-bold transition-colors">
                  Book Now
                </Link>
              </motion.div>
            </div>
          </div>
        </motion.nav>
      </div>
    </div>
  );
}